==> marko-widgets-6.6.5.tgz: package/README.md <==
Marko Widgets
=============

[![Build Status](https://travis-ci.org/marko-js/marko-widgets.svg?branch=master)](https://travis-ci.org/marko-js/marko-widgets)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/marko-js/marko-widgets)
[![NPM](https://img.shields.io/npm/v/marko-widgets.svg)](https://www.npmjs.com/package/marko-widgets)
[![Downloads](https://img.shields.io/npm/dm/marko-widgets.svg)](http://npm-stat.com/charts.html?package=marko-widgets)

![Marko Logo](https://raw.githubusercontent.com/marko-js/branding/master/marko-logo-small.png)

Marko Widgets extends the [Marko templating engine](https://github.com/marko-js/marko) to provide a simple and efficient mechanism for binding behavior to UI components rendered on either the server or in the browser. Learn more at [http://markojs.com/docs/marko-widgets/](http://markojs.com/docs/marko-widgets/).

# Changelog

See [CHANGELOG.md](CHANGELOG.md)

# Discuss

Chat channel: [![Gitter](https://badges.gitter.im/Join Chat.svg)](https://gitter.im/marko-js/marko-widgets?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Questions or comments can also be posted on the [Marko Widgets Github issues](https://github.com/marko-js/marko-widgets/issues) page.

# Maintainers

* [Patrick Steele-Idem](https://github.com/patrick-steele-idem) (Twitter: [@psteeleidem](http://twitter.com/psteeleidem))
* [Phillip Gates-Idem](https://github.com/philidem/) (Twitter: [@philidem](https://twitter.com/philidem))
* [Martin Aberer](https://github.com/tindli) (Twitter: [@metaCoffee](https://twitter.com/metaCoffee))

# Contribute

Pull Requests welcome. Please submit Github issues for any feature enhancements, bugs or documentation problems.

# License

Apache License v2.0

==> marko-widgets-7.0.1.tgz: package/README.md <==
Marko Widgets
=============

> **DEPRECATED:** Marko Widgets has been merged into Marko 4.0 and widgets are now referred to as components.  See the new [components](http://markojs.com/docs/components/) docs on [markojs.com](http://markojs.com/).

[![Build Status](https://travis-ci.org/marko-js/marko-widgets.svg?branch=master)](https://travis-ci.org/marko-js/marko-widgets)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/marko-js/marko-widgets)
[![NPM](https://img.shields.io/npm/v/marko-widgets.svg)](https://www.npmjs.com/package/marko-widgets)
[![Downloads](https://img.shields.io/npm/dm/marko-widgets.svg)](http://npm-stat.com/charts.html?package=marko-widgets)

![Marko Logo](https://raw.githubusercontent.com/marko-js/branding/master/marko-logo-small.png)

Marko Widgets extends the [Marko templating engine](https://github.com/marko-js/marko) to provide a simple and efficient mechanism for binding behavior to UI components rendered on either the server or in the browser. Learn more at [http://markojs.com/docs/marko-widgets/](http://v3.markojs.com/docs/marko-widgets/).

# Changelog

See [CHANGELOG.md](CHANGELOG.md)

# Discuss

Chat channel: [![Gitter](https://badges.gitter.im/Join Chat.svg)](https://gitter.im/marko-js/marko?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Questions or comments can also be posted on the [Marko Widgets Github issues](https://github.com/marko-js/marko-widgets/issues) page.

# Maintainers

* [Patrick Steele-Idem](https://github.com/patrick-steele-idem) (Twitter: [@psteeleidem](http://twitter.com/psteeleidem))
* [Phillip Gates-Idem](https://github.com/philidem/) (Twitter: [@philidem](https://twitter.com/philidem))
* [Martin Aberer](https://github.com/tindli) (Twitter: [@metaCoffee](https://twitter.com/metaCoffee))

# Contribute

Pull Requests welcome. Please submit Github issues for any feature enhancements, bugs or documentation problems.

# License

Apache License v2.0
